@@ -203,7 +203,7 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
 
    def search_dialog(self, widget, event, osso_rpc):
       settings = self.get_settings()
-      dialog = gtk.Dialog("Type A Search Query", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
+      dialog = gtk.Dialog("Search for", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
       search_button = dialog.add_button("Search", 1)
 
       image, url = self.get_data(settings['search_engine'])
@@ -222,7 +222,7 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
       
    def select_engine_dialog(self, widget, data=None):
       dialog = hildon.PickerDialog(gtk.Window())
-      dialog.set_title("Select A Site To Search")
+      dialog.set_title("Select Search Engine")
       
       selector = hildon.TouchSelector(text=True)
       searches = ["Google", "eBay", "General Shopping", "Dictionary.com", "Google Maps"]
